<?php
/**
 * Plugin Name:     AweBooking Payment
 * Plugin URI:      http://awethemes.com/plugins/awebooking
 * Description:     Allows you to enable payments online via gateways in guest checkout.
 * Author:          awethemes
 * Author URI:      http://awethemes.com
 * Text Domain:     awebooking-payment
 * Domain Path:     /languages
 * Version:         1.0.0-dev
 *
 * @package         AweBooking/Payment
 */

require_once trailingslashit( __DIR__ ) . 'vendor/autoload.php';

require_once __DIR__ . '/inc/payment-functions.php';

/**
 * Register awebooking gateways.
 *
 * @param  array $gateways The awebooking gateways.
 * @return array
 */
function awebooking_payment_register_gateways( $gateways ) {
	return array_merge( $gateways, [
		\AweBooking\Payment\Gateways\PayPal_Gateway::class,
		\AweBooking\Payment\Gateways\Stripe_Gateway::class,
	]);
}
add_filter( 'abrs_payment_gateways', 'awebooking_payment_register_gateways' );

/**
 * Register the payment routes.
 *
 * @see https://github.com/nikic/FastRoute#usage
 *
 * @param  \FastRoute\RouteCollector $route The route collector.
 * @return void
 */
function awebooking_payment_register_routes( $route ) {
	$route->get( '/payment/cancel/{booking:\d+}', 'AweBooking\Payment\Controllers\Payment_Controller@cancel' );
	$route->get( '/payment/complete/{gateway}/{booking:\d+}', 'AweBooking\Payment\Controllers\Payment_Controller@complete' );
}
add_action( 'abrs_register_routes', 'awebooking_payment_register_routes' );
